import { world, system, Player, EntityHealthComponent } from '@minecraft/server'

const overworld = world.getDimension("overworld")

function closestMods(location) {
    const options = {
        location: location,
        maxDistance: 8,
        minDistance: 0.5,
    };

    const entities = overworld.getEntities(options);

    return entities.filter(entity => {
        if (entity instanceof Player) {
            return false;
        }
        if (entity.typeId == "k:magic") return false
        return entity.hasComponent("health");
    });
}

system.runInterval(() => {
    const players = world.getAllPlayers();
    if (players.length === 0) {
        return; // Return if the list of players is empty
    }

    players.forEach((player) => {
        const closestEntities = closestMods(player.location);
        if (closestEntities.length === 0) {
            return; // Return if no closest entities found
        }

        closestEntities.forEach((entity) => {
            if (entity.typeId == "minecraft:armor_stand") return
            if (entity.typeId == "minecraft:bat") return
            const comp = entity.getComponent("health");
            let name = entity.nameTag ? entity.nameTag.trimEnd() : entity.typeId.replace("minecraft:", "");

            // Format the type ID length
            const typeIdLength = entity.typeId.replace("minecraft:", "").length;
            let typeIdFormatted = `${name.substr(0, typeIdLength)}`; // Truncate if it's too long

            const filledBars = "§c|§r".repeat(comp.currentValue);
            const emptyBars = "§0|§r".repeat(comp.effectiveMax - comp.currentValue);
            // Use name or formatted type ID
            entity.nameTag = `${name.length <= typeIdLength ? name : typeIdFormatted} [§c${filledBars + emptyBars}§r]`;
        });
    });
});